@@ -16,12 +16,13 @@ use App::Memcached::CLI::DataSource;
 use App::Memcached::CLI::Item;
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.5.1';
+use version; our $VERSION = 'v0.5.2';
 
 my $PROGRAM = basename $0;
 
 my %COMMAND2ALIASES = (
     help       => ['\h'],
+    version    => ['\v'],
     quit       => [qw(\q exit)],
     display    => [qw(\d)],
     stats      => [qw(\s)],
@@ -168,6 +169,10 @@ sub help {
             command => 'help',
             summary => 'Show help (this)',
         },
+        +{
+            command => 'version',
+            summary => 'Show server version',
+        },
         +{
             command => 'quit',
             summary => 'Exit',
@@ -341,6 +346,13 @@ sub delete {
     return 1;
 }
 
+sub version {
+    my $self = shift;
+    my $version = $self->{ds}->version;
+    print "$version\n";
+    return 1;
+}
+
 sub cachedump {
     my $self  = shift;
     my $class = shift;
